==> totoui-0.3.0.tgz: package/lib/icon.js <==
'use strict';

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; desc = parent = getter = undefined; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _minxinsClassNameMixin = require('./minxins/ClassNameMixin');

var _minxinsClassNameMixin2 = _interopRequireDefault(_minxinsClassNameMixin);

var Icon = (function (_React$Component) {
    _inherits(Icon, _React$Component);

    function Icon(props) {
        _classCallCheck(this, Icon);

        _get(Object.getPrototypeOf(Icon.prototype), 'constructor', this).call(this, props);
        for (var v in _minxinsClassNameMixin2['default']) {
            this[v] = _minxinsClassNameMixin2['default'][v].bind(this);
        }
    }

    _createClass(Icon, [{
        key: 'render',
        value: function render() {
            var classes = this.getClassSet();
            var props = this.props;
            var Component = props.href ? 'a' : props.componentTag;
            var prefixClass = this.prefixClass;
            var setClassNamespace = this.setClassNamespace;

            // del am-icon
            classes[setClassNamespace(props.classPrefix)] = false;

            // am-icon-[iconName]
            classes[prefixClass(props.icon)] = true;

            // am-icon-btn
            classes[prefixClass('btn')] = props.button;

            // button style
            props.button && props.amStyle && (classes[setClassNamespace(props.amStyle)] = true);

            // am-icon-fw
            classes[prefixClass('fw')] = props.fw;

            // am-icon-spin
            classes[prefixClass('spin')] = props.spin;

            return _react2['default'].createElement(Component, _react2['default'].__spread({}, props, { className: (0, _classnames2['default'])(classes, this.props.className) }), this.props.children);
        }
    }]);

    return Icon;
})(_react2['default'].Component);

Icon.displayName = "Icon";

Icon.propTypes = {
    amStyle: _react2['default'].PropTypes.string,
    fw: _react2['default'].PropTypes.bool,
    spin: _react2['default'].PropTypes.bool,
    button: _react2['default'].PropTypes.bool,
    size: _react2['default'].PropTypes.string,
    href: _react2['default'].PropTypes.string,
    componentTag: _react2['default'].PropTypes.node.isRequired,
    icon: _react2['default'].PropTypes.string.isRequired
};

Icon.defaultProps = {
    classPrefix: 'icon',
    componentTag: 'i'
};

module.exports = Icon;

==> totoui-0.5.1.tgz: package/lib/icon.js <==
'use strict';

var _createClass = (function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ('value' in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; })();

var _get = function get(_x, _x2, _x3) { var _again = true; _function: while (_again) { var object = _x, property = _x2, receiver = _x3; _again = false; if (object === null) object = Function.prototype; var desc = Object.getOwnPropertyDescriptor(object, property); if (desc === undefined) { var parent = Object.getPrototypeOf(object); if (parent === null) { return undefined; } else { _x = parent; _x2 = property; _x3 = receiver; _again = true; desc = parent = undefined; continue _function; } } else if ('value' in desc) { return desc.value; } else { var getter = desc.get; if (getter === undefined) { return undefined; } return getter.call(receiver); } } };

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _classnames = require('classnames');

var _classnames2 = _interopRequireDefault(_classnames);

var _mixinsClassNameMixin = require('./mixins/ClassNameMixin');

var _mixinsClassNameMixin2 = _interopRequireDefault(_mixinsClassNameMixin);

var Icon = (function (_React$Component) {
    _inherits(Icon, _React$Component);

    function Icon(props) {
        _classCallCheck(this, Icon);

        _get(Object.getPrototypeOf(Icon.prototype), 'constructor', this).call(this, props);
        for (var v in _mixinsClassNameMixin2['default']) {
            this[v] = _mixinsClassNameMixin2['default'][v].bind(this);
        }
    }

    _createClass(Icon, [{
        key: 'render',
        value: function render() {
            var classes = this.getClassSet();
            var props = this.props;
            var Component = props.href ? 'a' : props.componentTag;
            var prefixClass = this.prefixClass;
            var setClassNamespace = this.setClassNamespace;

            // del am-icon
            classes[setClassNamespace(props.classPrefix)] = false;

            // am-icon-[iconName]
            classes[prefixClass(props.icon)] = true;

            // am-icon-btn
            classes[prefixClass('btn')] = props.button;

            // button style
            props.button && props.amStyle && (classes[setClassNamespace(props.amStyle)] = true);

            // am-icon-fw
            classes[prefixClass('fw')] = props.fw;

            // am-icon-spin
            classes[prefixClass('spin')] = props.spin;

            return _react2['default'].createElement(Component, _react2['default'].__spread({}, props, { className: (0, _classnames2['default'])(classes, this.props.className) }), this.props.children);
        }
    }]);

    return Icon;
})(_react2['default'].Component);

Icon.displayName = "Icon";

Icon.propTypes = {
    amStyle: _react2['default'].PropTypes.string,
    fw: _react2['default'].PropTypes.bool,
    spin: _react2['default'].PropTypes.bool,
    button: _react2['default'].PropTypes.bool,
    size: _react2['default'].PropTypes.string,
    href: _react2['default'].PropTypes.string,
    componentTag: _react2['default'].PropTypes.node.isRequired,
    icon: _react2['default'].PropTypes.string.isRequired
};

Icon.defaultProps = {
    classPrefix: 'icon',
    componentTag: 'i'
};

module.exports = Icon;
